==> spip_3.2.11.orig.tar.xz: plugins-dist/sites/lang/sites_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Fallu na sindicación: el backend indicáu ye indescifrable o nun tien dengún artículu.',
	'avis_echec_syndication_02' => 'Fallu na sindicación: ye imposible allegase al backend d’esti sitiu.',
	'avis_site_introuvable' => 'Nun s’atopa el sitiu',
	'avis_site_syndique_probleme' => 'Atención: la sindicación de esti sitiu atopose con un problema; poro, el sistema ta interrumpíu de momentu. Verifica les señes del archivu de sindicación del sitiu (<b>@url_syndic@</b>), y tenta recuperar otra vegada la información.',
	'avis_sites_probleme_syndication' => 'Hubo un problema cola sindicación d’estos sitios',
	'avis_sites_syndiques_probleme' => 'Estos sitios sindicaos tuvieron problemes',

	// B
	'bouton_radio_modere_posteriori' => 'moderación a posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderación a priori', # MODIF
	'bouton_radio_non_syndication' => 'Ensin sindicación',
	'bouton_radio_syndication' => 'Sindicación:',

	// E
	'entree_adresse_fichier_syndication' => 'Señes de l’archivu de sindicación:',
	'entree_adresse_site' => '<b>Señes del sitiu</b> [Obligatorio]',
	'entree_description_site' => 'Descripción del sitiu',

	// F
	'form_prop_nom_site' => 'Nome del sitiu',

	// I
	'icone_modifier_site' => 'Iguar esti sitiu',
	'icone_referencer_nouveau_site' => 'Referenciar un nuevu sitiu',
	'icone_voir_sites_references' => 'Ver los sitios referenciaos',
	'info_1_article_syndique' => '1 artículu sindicáu',
	'info_1_site' => '1 sitiu web',
	'info_a_valider' => '[a validar]',
	'info_aucun_article_syndique' => 'Dengún artículu sindicáu',
	'info_aucun_site' => 'Dengún sitiu',
	'info_bloquer' => 'bloquiar',
	'info_bloquer_lien' => 'bloquiar esti enllace',
	'info_derniere_syndication' => 'La cabera sindicación d’esti sitiu efeutuose el',
	'info_liens_syndiques_1' => 'enllaces sindicaos',
	'info_liens_syndiques_2' => 'tan esperando validación.',
	'info_nb_articles_syndiques' => '@nb@ artículos sindicaos',
	'info_nb_sites' => '@nb@ sitios',
	'info_nom_site_2' => '<b>Nome del sitiu</b> [Obligatoriu]',
	'info_panne_site_syndique' => 'Sitiu sindicau ensin serviciu',
	'info_probleme_grave' => 'problema de',
	'info_question_proposer_site' => '¿Quién pue proponer sitios referenciaos?',
	'info_retablir_lien' => 'reestablecer esti enllaz',
	'info_site_attente' => 'Sitiu Web esperando validación',
	'info_site_propose' => 'Sitiu propuestu el:',
	'info_site_reference' => 'Sitiu referenciáu en llinia',
	'info_site_refuse' => 'Sitiu Web refugáu',
	'info_site_syndique' => 'Esti sitiu ta sindicáu...', # MODIF
	'info_site_valider' => 'Sitios a validar',
	'info_sites_referencer' => 'Referenciar un sitiu Web',
	'info_sites_refuses' => 'Los sitios refugaos',
	'info_statut_site_1' => 'Esti sitiu ta:',
	'info_statut_site_2' => 'Espublizáu',
	'info_statut_site_3' => 'Propuestu',
	'info_statut_site_4' => 'Na basoria', # MODIF
	'info_syndication' => 'sindicación:',
	'info_syndication_articles' => 'artículu(os)',
	'item_bloquer_liens_syndiques' => 'Torgar los enllaces sindicaos pa validación',
	'item_gerer_annuaire_site_web' => 'Xestionar una llista de sitios Web',
	'item_non_bloquer_liens_syndiques' => 'Nun bloquiar los enllaces apaecidos na sindicación',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’anuariu de sitios Web',
	'item_non_utiliser_syndication' => 'Nun utilizar la sindicación automática',
	'item_utiliser_syndication' => 'Utilizar la sindicación automática',

	// L
	'lien_mise_a_jour_syndication' => 'Actualizar agora',
	'lien_nouvelle_recuperation' => 'Tentar una nueva recuperación de los datos',

	// S
	'syndic_choix_moderation' => '¿Que se fai colos próximos enllaces que vengan d’esti sitiu?',
	'syndic_choix_oublier' => '¿Qué se fai colos enllaces que nun figuren nel archivu de sindicación?',
	'syndic_choix_resume' => 'Dellos sitios esparden el testu completu de los artículos. Cuando el mesmu tea disponible quies sindicar:',
	'syndic_lien_obsolete' => 'enllaz vieyu',
	'syndic_option_miroir' => 'bloquialos automáticamente',
	'syndic_option_oubli' => 'desanicialos (tres @mois@ meses)',
	'syndic_option_resume_non' => 'el conteníu ensembre de los artículos (en formatu HTML)',
	'syndic_option_resume_oui' => 'un simple resume (en formatu testu)',
	'syndic_options' => 'Opciones de sindicación:',

	// T
	'texte_liens_sites_syndiques' => 'Los enllaces surdíos de los sitios sindicaos
   puen bloquiase a priori; l’axuste de
   más embaxo indica l’axuste por omisión de
   los sitios sindicaos tres de crease. Llueu
   ye posible, sicasí, desbloquiar cada
   enllaz individualmente, o escoyer, sitiu
   por sitiu, si bloquiar los enllaces que
   vengan de tal o cual sitiu.', # MODIF
	'texte_messages_publics' => 'Mensaxes públicos de l’artículu:',
	'texte_non_fonction_referencement' => 'Seique prefieras nun usar esta función automática, y remanar tú mesmu los elementos tocantes a esti sitiu...', # MODIF
	'texte_referencement_automatique' => '<b>Referenciamientu automatizáu d’un sitiu</b><br />Pues referenciar rápidamente un sitiu Web conseñando embaxo les señes URL deseáes, o les señes del so archivu de sindicación. SPIP va recuperar automáticamente la información tocante a esti sitiu (títulu, descripción...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Has de verificar la información ufrida por <tt>@url@</tt> enantes de grabar.',
	'texte_syndication' => 'Ye posible recuperar automaticamente, cuando un sitiu web lo permite,
  la llista de les novedáes. Para esto, hai que activar la sindicación.
  <blockquote><i>Dellos agospiadores web desactiven esta función;
  si ye’l casu, nun vas poder usar la sindicación de conteníos
  dende’l to sitiu web.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artículos sindicaos vinientes d’esti sitiu',
	'titre_dernier_article_syndique' => 'Caberos artículos sindicaos',
	'titre_page_sites_tous' => 'Los sitios referenciaos',
	'titre_referencement_sites' => 'Referenciación de sitios y sindicación',
	'titre_site_numero' => 'SITIU NÚMBERU:',
	'titre_sites_proposes' => 'Los sitios propuestos',
	'titre_sites_references_rubrique' => 'Los sitios referenciaos na estaya',
	'titre_sites_syndiques' => 'Los sitios sindicaos',
	'titre_sites_tous' => 'Los sitios referenciaos',
	'titre_syndication' => 'Sindicación de sitios'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'Fallu na sindicación: el backend indicáu ye indescifrable o nun tien dengún artículu.',
	'avis_echec_syndication_02' => 'Fallu na sindicación: ye imposible allegase al backend d’esti sitiu.',
	'avis_site_introuvable' => 'Nun s’atopa el sitiu',
	'avis_site_syndique_probleme' => 'Atención: la sindicación de esti sitiu atopose con un problema; poro, el sistema ta interrumpíu de momentu. Verifica les señes del archivu de sindicación del sitiu (<b>@url_syndic@</b>), y tenta recuperar otra vegada la información.',
	'avis_sites_probleme_syndication' => 'Hubo un problema cola sindicación d’estos sitios',
	'avis_sites_syndiques_probleme' => 'Estos sitios sindicaos tuvieron problemes',

	// B
	'bouton_radio_modere_posteriori' => 'moderación a posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderación a priori', # MODIF
	'bouton_radio_non_syndication' => 'Ensin sindicación',
	'bouton_radio_syndication' => 'Sindicación:',

	// E
	'entree_adresse_fichier_syndication' => 'Señes de l’archivu de sindicación:',
	'entree_adresse_site' => '<b>Señes del sitiu</b> [Obligatorio]',
	'entree_description_site' => 'Descripción del sitiu',

	// F
	'form_prop_nom_site' => 'Nome del sitiu',

	// I
	'icone_modifier_site' => 'Iguar esti sitiu',
	'icone_referencer_nouveau_site' => 'Referenciar un nuevu sitiu',
	'icone_voir_sites_references' => 'Ver los sitios referenciaos',
	'info_1_article_syndique' => '1 artículu sindicáu',
	'info_1_site' => '1 sitiu web',
	'info_a_valider' => '[a validar]',
	'info_aucun_article_syndique' => 'Dengún artículu sindicáu',
	'info_aucun_site' => 'Dengún sitiu',
	'info_bloquer' => 'bloquiar',
	'info_bloquer_lien' => 'bloquiar esti enllace',
	'info_derniere_syndication' => 'La cabera sindicación d’esti sitiu efeutuose el',
	'info_liens_syndiques_1' => 'enllaces sindicaos',
	'info_liens_syndiques_2' => 'tan esperando validación.',
	'info_nb_articles_syndiques' => '@nb@ artículos sindicaos',
	'info_nb_sites' => '@nb@ sitios',
	'info_nom_site_2' => '<b>Nome del sitiu</b> [Obligatoriu]',
	'info_panne_site_syndique' => 'Sitiu sindicau ensin serviciu',
	'info_probleme_grave' => 'problema de',
	'info_question_proposer_site' => '¿Quién pue proponer sitios referenciaos?',
	'info_retablir_lien' => 'reestablecer esti enllaz',
	'info_site_attente' => 'Sitiu Web esperando validación',
	'info_site_propose' => 'Sitiu propuestu el:',
	'info_site_reference' => 'Sitiu referenciáu en llinia',
	'info_site_refuse' => 'Sitiu Web refugáu',
	'info_site_syndique' => 'Esti sitiu ta sindicáu...', # MODIF
	'info_site_valider' => 'Sitios a validar',
	'info_sites_referencer' => 'Referenciar un sitiu Web',
	'info_sites_refuses' => 'Los sitios refugaos',
	'info_statut_site_1' => 'Esti sitiu ta:',
	'info_statut_site_2' => 'Espublizáu',
	'info_statut_site_3' => 'Propuestu',
	'info_statut_site_4' => 'Na basoria', # MODIF
	'info_syndication' => 'sindicación:',
	'info_syndication_articles' => 'artículu(os)',
	'item_bloquer_liens_syndiques' => 'Torgar los enllaces sindicaos pa validación',
	'item_gerer_annuaire_site_web' => 'Xestionar una llista de sitios Web',
	'item_non_bloquer_liens_syndiques' => 'Nun bloquiar los enllaces apaecidos na sindicación',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’anuariu de sitios Web',
	'item_non_utiliser_syndication' => 'Nun utilizar la sindicación automática',
	'item_utiliser_syndication' => 'Utilizar la sindicación automática',

	// L
	'lien_mise_a_jour_syndication' => 'Actualizar agora',
	'lien_nouvelle_recuperation' => 'Tentar una nueva recuperación de los datos',

	// S
	'syndic_choix_moderation' => '¿Que se fai colos próximos enllaces que vengan d’esti sitiu?',
	'syndic_choix_oublier' => '¿Qué se fai colos enllaces que nun figuren nel archivu de sindicación?',
	'syndic_choix_resume' => 'Dellos sitios esparden el testu completu de los artículos. Cuando el mesmu tea disponible quies sindicar:',
	'syndic_lien_obsolete' => 'enllaz vieyu',
	'syndic_option_miroir' => 'bloquialos automáticamente',
	'syndic_option_oubli' => 'desanicialos (tres @mois@ meses)',
	'syndic_option_resume_non' => 'el conteníu ensembre de los artículos (en formatu HTML)',
	'syndic_option_resume_oui' => 'un simple resume (en formatu testu)',
	'syndic_options' => 'Opciones de sindicación:',

	// T
	'texte_liens_sites_syndiques' => 'Los enllaces surdíos de los sitios sindicaos
   puen bloquiase a priori; l’axuste de
   más embaxo indica l’axuste por omisión de
   los sitios sindicaos tres de crease. Llueu
   ye posible, sicasí, desbloquiar cada
   enllaz individualmente, o escoyer, sitiu
   por sitiu, si bloquiar los enllaces que
   vengan de tal o cual sitiu.', # MODIF
	'texte_messages_publics' => 'Mensaxes públicos de l’artículu:',
	'texte_non_fonction_referencement' => 'Seique prefieras nun usar esta función automática, y remanar tú mesmu los elementos tocantes a esti sitiu...', # MODIF
	'texte_referencement_automatique' => '<b>Referenciamientu automatizáu d’un sitiu</b><br />Pues referenciar rápidamente un sitiu Web conseñando embaxo les señes URL deseáes, o les señes del so archivu de sindicación. SPIP va recuperar automáticamente la información tocante a esti sitiu (títulu, descripción...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Has de verificar la información ufrida por <tt>@url@</tt> enantes de grabar.',
	'texte_syndication' => 'Ye posible recuperar automaticamente, cuando un sitiu web lo permite,
  la llista de les novedáes. Para esto, hai que activar la sindicación.
  <blockquote><i>Dellos agospiadores web desactiven esta función;
  si ye’l casu, nun vas poder usar la sindicación de conteníos
  dende’l to sitiu web.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artículos sindicaos vinientes d’esti sitiu',
	'titre_dernier_article_syndique' => 'Caberos artículos sindicaos',
	'titre_page_sites_tous' => 'Los sitios referenciaos',
	'titre_referencement_sites' => 'Referenciación de sitios y sindicación',
	'titre_site_numero' => 'SITIU NÚMBERU:',
	'titre_sites_proposes' => 'Los sitios propuestos',
	'titre_sites_references_rubrique' => 'Los sitios referenciaos na estaya',
	'titre_sites_syndiques' => 'Los sitios sindicaos',
	'titre_sites_tous' => 'Los sitios referenciaos',
	'titre_syndication' => 'Sindicación de sitios',
];
